@@ -1,10 +1,9 @@
 package MooseX::ShortCut::BuildInstance;
 our $AUTHORITY = 'cpan:JANDREW';
-# ABSTRACT: A shortcut to build Moose instances
-
-use version 0.77; our $VERSION = version->declare('v1.40.2');
-###LogSD	warn "You uncovered internal logging statements for MooseX::ShortCut::BuildInstance-$VERSION";
+use version 0.77; our $VERSION = version->declare('v1.42.0');
+###InternalBuilDInstancE	warn "You uncovered internal logging statements for MooseX::ShortCut::BuildInstance-$VERSION" if !$ENV{hide_warn_for_test};
 use 5.010;
+use utf8;
 use Moose 2.1213;
 use Moose::Meta::Class;
 use Types::Standard 1.000 qw( Bool is_HashRef );
@@ -23,9 +22,7 @@ use lib	'../../../lib',;
 use MooseX::ShortCut::BuildInstance::Types 1.036 qw(
 		BuildClassDict
 	);
-###LogSD	use Log::Shiras::Telephone;
-###LogSD	use Log::Shiras::UnhideDebug;
-use MooseX::ShortCut::BuildInstance::UnhideDebug;
+###InternalBuilDInstancE	use Log::Shiras::Telephone;
 
 #########1 Package Variables  3#########4#########5#########6#########7#########8#########9
 
@@ -50,17 +47,17 @@ my 	@add_class_args = qw(
 sub build_class{
 	my	$temp_args = ( ( scalar( @_ ) == 1 ) ? $_[0] : { @_ } );
 	my	$args = $should_clone_args ? clone( $temp_args ) : $temp_args;
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> 'build_class', );
-	###LogSD		$phone->talk( level => 'info', message =>[
-	###LogSD			"Arrived at build_class with args:", $args, ] );
+	###InternalBuilDInstancE	my	$phone = Log::Shiras::Telephone->new(
+	###InternalBuilDInstancE					name_space 	=> 'build_class', );
+	###InternalBuilDInstancE		$phone->talk( level => 'info', message =>[
+	###InternalBuilDInstancE			"Arrived at build_class with args:", $args, ] );
 	my ( $class_args, $i, $can_build, $warning, @warn_list, $pre_exists );
 	for my $key ( @init_class_args ){
-		###LogSD	$phone->talk( level => 'debug', message =>[
-		###LogSD		"Processing the class argument: $key", ] );
+		###InternalBuilDInstancE	$phone->talk( level => 'debug', message =>[
+		###InternalBuilDInstancE		"Processing the class argument: $key", ] );
 		if( exists $args->{$key} ){
-			###LogSD	$phone->talk( level => 'debug', message =>[
-			###LogSD		'Processing the values:', $args->{$key}, ] );
+			###InternalBuilDInstancE	$phone->talk( level => 'debug', message =>[
+			###InternalBuilDInstancE		'Processing the values:', $args->{$key}, ] );
 			$class_args->{$key} = $args->{$key};
 			if( $key eq 'package' ){
 				if( $built_classes->{$args->{$key}} ){
@@ -68,8 +65,8 @@ sub build_class{
 					if( !$re_use_classes ){
 						push @warn_list, 'You already built the class: ' . $args->{$key};
 						$warning = 1;
-						###LogSD	$phone->talk( level => 'warn', message =>[
-						###LogSD		"unmutablizing the class ...", @warn_list ] );
+						###InternalBuilDInstancE	$phone->talk( level => 'warn', message =>[
+						###InternalBuilDInstancE		"unmutablizing the class ...", @warn_list ] );
 						$args->{$key}->meta->make_mutable;
 					}
 				}
@@ -78,102 +75,102 @@ sub build_class{
 			delete $args->{$key};
 		}elsif( $key eq 'package' ){
 			$class_args->{$key} = "ANONYMOUS_SHIRAS_MOOSE_CLASS_" . ++$anonymous_class_count;
-			###LogSD	$phone->talk( level => 'warn', message =>[
-			###LogSD		"missing a package value - using: " . $class_args->{$key} ] );
+			###InternalBuilDInstancE	$phone->talk( level => 'warn', message =>[
+			###InternalBuilDInstancE		"missing a package value - using: " . $class_args->{$key} ] );
 		}elsif( $key eq 'superclasses' ){
 			### <where> - missing the superclass ...
 			$class_args->{$key} = [ 'Anonymous::Shiras::Moose::Class' ],
-			###LogSD	$phone->talk( level => 'warn', message =>[
-			###LogSD		"missing the superclass value - using: ", $class_args->{$key} ] );
+			###InternalBuilDInstancE	$phone->talk( level => 'warn', message =>[
+			###InternalBuilDInstancE		"missing the superclass value - using: ", $class_args->{$key} ] );
 		}
 	}
 	if( $warning ){
 		push @warn_list, 'The old class definitions will be overwritten with args:', Dumper( $class_args );
 		cluck( join( "\n", @warn_list ) );
-		###LogSD	$phone->talk( level => 'warn', message =>[
-		###LogSD		'The old class definitions will be overwritten with args:',  $class_args ] );
+		###InternalBuilDInstancE	$phone->talk( level => 'warn', message =>[
+		###InternalBuilDInstancE		'The old class definitions will be overwritten with args:',  $class_args ] );
 	}else{
 		my $package_key = $class_args->{package};
 		$package_key =~ s/::/\//g;
 		$package_key .= '.pm';
 		if( exists $INC{$package_key} ){
 			if( $re_use_classes ){
-				###LogSD	$phone->talk( level => 'warn', message =>[
-				###LogSD		"Already built the class: $class_args->{package}" ] );
+				###InternalBuilDInstancE	$phone->talk( level => 'warn', message =>[
+				###InternalBuilDInstancE		"Already built the class: $class_args->{package}" ] );
 				return $class_args->{package};# Don't rebuild if you are re-using
 			}
 			cluck "Overwriting a pre-built and loaded class: " . $class_args->{package} ;
-			###LogSD	$phone->talk( level => 'warn', message =>[
-			###LogSD		"unmutablizing the class: $class_args->{package}" ] );
+			###InternalBuilDInstancE	$phone->talk( level => 'warn', message =>[
+			###InternalBuilDInstancE		"unmutablizing the class: $class_args->{package}" ] );
 			$class_args->{package}->meta->make_mutable;
 		}
 	}
 	my $want_array = ( caller(0) )[5];
-	###LogSD	$phone->talk( level => 'trace', message =>[
-	###LogSD		'class args:', $class_args, 'remaining arguments:', $args,
-	###LogSD		"want array: $want_array", "Pre exists state: " . ($pre_exists//''), 
-	###LogSD		"\$warning state: " . ($warning//''),	'finalize the class name or load a new one ...' ] );
+	###InternalBuilDInstancE	$phone->talk( level => 'trace', message =>[
+	###InternalBuilDInstancE		'class args:', $class_args, 'remaining arguments:', $args,
+	###InternalBuilDInstancE		"want array: $want_array", "Pre exists state: " . ($pre_exists//''),
+	###InternalBuilDInstancE		"\$warning state: " . ($warning//''),	'finalize the class name or load a new one ...' ] );
 	my	$class_name = ( $pre_exists and !$warning ) ?
 			$class_args->{package} :
 			Moose::Meta::Class->create( %{$class_args} )->name;
-	###LogSD	$phone->talk( level => 'debug', message =>[
-	###LogSD		'class to this point: ' . $class_name->dump( 2 ) ] );
+	###InternalBuilDInstancE	$phone->talk( level => 'debug', message =>[
+	###InternalBuilDInstancE		'class to this point: ' . $class_name->dump( 2 ) ] );
 	if( !$class_name->meta->is_mutable and
 		(	exists $args->{add_attributes} or
 			exists $args->{add_methods} or
 			exists $args->{add_roles_in_sequence} ) ){
-		###LogSD	$phone->talk( level => 'info', message =>[
-		###LogSD		'Unmutablizing the class ...' ] );
+		###InternalBuilDInstancE	$phone->talk( level => 'info', message =>[
+		###InternalBuilDInstancE		'Unmutablizing the class ...' ] );
 		$class_name->meta->make_mutable;
 	}
 	if( exists $args->{add_attributes} ){
-		###LogSD	$phone->talk( level => 'debug', message =>[
-		###LogSD		"Found attributes to add" ] );
+		###InternalBuilDInstancE	$phone->talk( level => 'debug', message =>[
+		###InternalBuilDInstancE		"Found attributes to add" ] );
 		my	$meta = $class_name->meta;
 		for my $attribute ( keys %{$args->{add_attributes}} ){
-			###LogSD	$phone->talk( level => 'debug', message =>[
-			###LogSD		"adding attribute named: $attribute" ] );
+			###InternalBuilDInstancE	$phone->talk( level => 'debug', message =>[
+			###InternalBuilDInstancE		"adding attribute named: $attribute" ] );
 			$meta->add_attribute( $attribute => $args->{add_attributes}->{$attribute} );
 		}
 		delete $args->{add_attributes};
 	}
 	if( exists $args->{add_methods} ){
-		###LogSD	$phone->talk( level => 'debug', message =>[
-		###LogSD		"Found roles to add" ] );
+		###InternalBuilDInstancE	$phone->talk( level => 'debug', message =>[
+		###InternalBuilDInstancE		"Found roles to add" ] );
 		my	$meta = $class_name->meta;
 		for my $method ( keys %{$args->{add_methods}} ){
-			###LogSD	$phone->talk( level => 'debug', message =>[
-			###LogSD		"adding method named: $method" ] );
+			###InternalBuilDInstancE	$phone->talk( level => 'debug', message =>[
+			###InternalBuilDInstancE		"adding method named: $method" ] );
 			$meta->add_method( $method => $args->{add_methods}->{$method} );
 		}
 		delete $args->{add_methods};
 	}
 	if( exists $args->{add_roles_in_sequence} ){
-		###LogSD	$phone->talk( level => 'debug', message =>[
-		###LogSD		"Found roles_in_sequence to add" ] );
+		###InternalBuilDInstancE	$phone->talk( level => 'debug', message =>[
+		###InternalBuilDInstancE		"Found roles_in_sequence to add" ] );
 		for my $role ( @{$args->{add_roles_in_sequence}} ){
-			###LogSD	$phone->talk( level => 'debug', message =>[ "adding role: $role" ] );
+			###InternalBuilDInstancE	$phone->talk( level => 'debug', message =>[ "adding role: $role" ] );
 			apply_all_roles( $class_name, $role );
 		}
 		delete $args->{add_roles_in_sequence};
 	}
 	if( $make_classes_immutable ){
-		###LogSD	$phone->talk( level => 'info', message =>[
-		###LogSD		'Immutablizing the class ...' ] );
+		###InternalBuilDInstancE	$phone->talk( level => 'info', message =>[
+		###InternalBuilDInstancE		'Immutablizing the class ...' ] );
 		$class_name->meta->make_immutable;
 	}
-	###LogSD	$phone->talk( level => 'info', message =>[
-	###LogSD		"returning: $class_name" ] );
+	###InternalBuilDInstancE	$phone->talk( level => 'info', message =>[
+	###InternalBuilDInstancE		"returning: $class_name" ] );
 	return $class_name;
 }
 
 sub build_instance{
 	my	$temp_args = is_HashRef( $_[0] ) ? $_[0] : { @_ };
 	my	$args = $should_clone_args ? clone( $temp_args ) : $temp_args;
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> 'build_instance', );
-	###LogSD		$phone->talk( level => 'info', message =>[
-	###LogSD			"Arrived at build_instance with args:", $args, ] );
+	###InternalBuilDInstancE	my	$phone = Log::Shiras::Telephone->new(
+	###InternalBuilDInstancE					name_space 	=> 'build_instance', );
+	###InternalBuilDInstancE		$phone->talk( level => 'info', message =>[
+	###InternalBuilDInstancE			"Arrived at build_instance with args:", $args, ] );
 	my	$class_args;
 	for my $key ( @init_class_args, @add_class_args ){
 		if( exists $args->{$key} ){
@@ -181,13 +178,13 @@ sub build_instance{
 			delete $args->{$key};
 		}
 	}
-	###LogSD	$phone->talk( level => 'trace', message =>[
-	###LogSD		'Reduced arguments:', $args,
-	###LogSD		'Class building arguments:', $class_args, ] );
+	###InternalBuilDInstancE	$phone->talk( level => 'trace', message =>[
+	###InternalBuilDInstancE		'Reduced arguments:', $args,
+	###InternalBuilDInstancE		'Class building arguments:', $class_args, ] );
 	my $class = build_class( $class_args );
-	###LogSD	$phone->talk( level => 'warn', message =>[
-	###LogSD		"Built class name: $class",
-	###LogSD		"To get instance now applying args:", $args, ] );
+	###InternalBuilDInstancE	$phone->talk( level => 'trace', message =>[
+	###InternalBuilDInstancE		"Built class name: $class",
+	###InternalBuilDInstancE		"To get instance now applying args:", $args, ] );
 	my $instance;
 	eval '$instance = $class->new( %$args )';
 	if( $@ ){
@@ -200,44 +197,44 @@ sub build_instance{
 			}
 		}
 		$message =~ s/\)\n;/\);/g;
-		###LogSD	if( 1 ){
-		###LogSD		$phone->talk( level => 'warn', message =>[
-		###LogSD			"Failed to build -$class- for: $message", ] );
-		###LogSD	}else{
+		###InternalBuilDInstancE	if( 1 ){
+		###InternalBuilDInstancE		$phone->talk( level => 'warn', message =>[
+		###InternalBuilDInstancE			"Failed to build -$class- for: $message", ] );
+		###InternalBuilDInstancE	}else{
 		cluck $message;
-		###LogSD	}
+		###InternalBuilDInstancE	}
 	}else{
-		###LogSD	$phone->talk( level => 'trace', message =>[
-		###LogSD		"Built instance:", $instance, ] );
+		###InternalBuilDInstancE	$phone->talk( level => 'trace', message =>[
+		###InternalBuilDInstancE		"Built instance:", $instance, ] );
 		return $instance;
 	}
 }
 
 sub should_re_use_classes{
 	my ( $bool, ) = @_;
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> 'should_re_use_classes', );
-	###LogSD		$phone->talk( level => 'info', message =>[
-	###LogSD			"setting \$re_use_classes to: $bool", ] );
+	###InternalBuilDInstancE	my	$phone = Log::Shiras::Telephone->new(
+	###InternalBuilDInstancE					name_space 	=> 'should_re_use_classes', );
+	###InternalBuilDInstancE		$phone->talk( level => 'info', message =>[
+	###InternalBuilDInstancE			"setting \$re_use_classes to: $bool", ] );
 	$re_use_classes = ( $bool ) ? 1 : 0 ;
 }
 
 sub set_class_immutability{
 	my ( $bool, ) = @_;
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> 'set_class_immutability', );
-	###LogSD		$phone->talk( level => 'info', message =>[
-	###LogSD			"setting \$make_immutable_classes to; $bool", ] );
+	###InternalBuilDInstancE	my	$phone = Log::Shiras::Telephone->new(
+	###InternalBuilDInstancE					name_space 	=> 'set_class_immutability', );
+	###InternalBuilDInstancE		$phone->talk( level => 'info', message =>[
+	###InternalBuilDInstancE			"setting \$make_immutable_classes to; $bool", ] );
 	$make_classes_immutable = ( $bool ) ? 1 : 0 ;
 }
 
 sub set_args_cloning{
 	my ( $bool, ) = @_;
-	###LogSD	my	$phone = Log::Shiras::Telephone->new(
-	###LogSD					name_space 	=> 'set_args_cloning', );
+	###InternalBuilDInstancE	my	$phone = Log::Shiras::Telephone->new(
+	###InternalBuilDInstancE					name_space 	=> 'set_args_cloning', );
 	$should_clone_args = !!$bool;
-	###LogSD		$phone->talk( level => 'info', message =>[
-	###LogSD			"set \$should_clone_args to; $should_clone_args", ] );
+	###InternalBuilDInstancE		$phone->talk( level => 'info', message =>[
+	###InternalBuilDInstancE			"set \$should_clone_args to; $should_clone_args", ] );
 }
 
 #########1 Phinish strong     3#########4#########5#########6#########7#########8#########9
@@ -291,15 +288,15 @@ MooseX::ShortCut::BuildInstance - A shortcut to build Moose instances
 =end html
 
 =head1 SYNOPSIS
-    
+
 	#!/user/bin/env perl
 	package Mineral;
 	use Moose;
 	use Types::Standard qw( Enum );
 
-	has 'type' =>( 
+	has 'type' =>(
 			isa => Enum[qw( Quartz Diamond Basalt Granite )],
-			is => 'ro' 
+			is => 'ro'
 		);
 
 	package Identity;
@@ -347,7 +344,7 @@ MooseX::ShortCut::BuildInstance - A shortcut to build Moose instances
 	print'My ' . $Gonzalo->meta->name . ' made from -' . $Gonzalo->type . '- (a ' .
 	( join ', ', $Gonzalo->meta->superclasses ) . ') is called -' . $Gonzalo->name . "-\n";
 	done_testing();
-    
+
     ##############################################################################
     # Output of SYNOPSIS
     # 01:ok 1 - Check that the Pet::Rock has an -Identity-
@@ -358,15 +355,15 @@ MooseX::ShortCut::BuildInstance - A shortcut to build Moose instances
     # 02:My Pet::Rock made from -Granite- (a Mineral) is called -Gonzalo-
     # 03:1..3
     ##############################################################################
-    
+
 =head1 DESCRIPTION
 
-This module is a shortcut to custom build L<Moose> class instances on the fly.  
-The goal is to compose unique instances of Moose classes on the fly using a single 
-function call with information describing required attributes, methods, inherited 
-classes, and roles as well as any desired instance settings.  This package will 
-check for and fill in any missing pieces as needed so that your call can either be 
-complex or very simple.  The goal is to provide configurable instance building 
+This module is a shortcut to custom build L<Moose> class instances on the fly.
+The goal is to compose unique instances of Moose classes on the fly using a single
+function call with information describing required attributes, methods, inherited
+classes, and roles as well as any desired instance settings.  This package will
+check for and fill in any missing pieces as needed so that your call can either be
+complex or very simple.  The goal is to provide configurable instance building
 without stringing together a series of Class-E<gt>method( %args ) calls.
 
 The package can also be used as a class factory with the L<should_re_use_classes
@@ -377,40 +374,40 @@ Even though this is a Moose based class it provides a functional interface.
 =head1 WARNING(S)
 
 Moose (and I think perl 5) can't have two classes with the same name but
-different guts coexisting! This means that if you build a class (package) name 
-on the fly while building an instance and then recompose a new class (package) with 
-the same name but different functionality (different attributes, methods, inherited 
-classes or roles) while composing a new instance on the fly then all calls 
-to the old instance will use the new class functionality for execution. (Usually 
-causing hard to troubleshoot failures).  This is also true if you re-build a 
+different guts coexisting! This means that if you build a class (package) name
+on the fly while building an instance and then recompose a new class (package) with
+the same name but different functionality (different attributes, methods, inherited
+classes or roles) while composing a new instance on the fly then all calls
+to the old instance will use the new class functionality for execution. (Usually
+causing hard to troubleshoot failures).  This is also true if you re-build a
 prebuilt class name inititally installed with 'use'.
 
 MooseX::ShortCut::BuildInstance will warn if you overwrite named classes (packages)
-built on top of another class (package) also built by MooseX::ShortCut::BuildInstance.  
-If you are using the 'build_instance' method to generate multiple instances of 
-the same class (by 'package' name) with different attribute settings but built 
-with the same functionality then you need to understand the purpose of the 
-L<$re_use_classes|/$MooseX::ShortCut::BuildInstance::re_use_classes> global variable.  
-An alternative to multiple calls straight to 'build_instance' is to call 
-L<build_class|/build_class( %args|\%args )> separately and then just call -E<gt>new 
-against the resulting class name over and over again.  Another alternative is to 
-leave the 'package' argument out of 'build_instance' and let this class create a 
+built on top of another class (package) also built by MooseX::ShortCut::BuildInstance.
+If you are using the 'build_instance' method to generate multiple instances of
+the same class (by 'package' name) with different attribute settings but built
+with the same functionality then you need to understand the purpose of the
+L<$re_use_classes|/$MooseX::ShortCut::BuildInstance::re_use_classes> global variable.
+An alternative to multiple calls straight to 'build_instance' is to call
+L<build_class|/build_class( %args|\%args )> separately and then just call -E<gt>new
+against the resulting class name over and over again.  Another alternative is to
+leave the 'package' argument out of 'build_instance' and let this class create a
 unique by-instance anonymous class/package name.
 
-MooseX::ShortCut::BuildInstance will also warn (but not stop you) if you try to 
+MooseX::ShortCut::BuildInstance will also warn (but not stop you) if you try to
 overwrite a pre-loaded package initially installed with 'use' or 'require'.
 
-The Types module in this package uses L<Type::Tiny> which can, in the 
-background, use L<Type::Tiny::XS>.  While in general this is a good thing you will 
-need to make sure that Type::Tiny::XS is version 0.010 or newer since the older 
+The Types module in this package uses L<Type::Tiny> which can, in the
+background, use L<Type::Tiny::XS>.  While in general this is a good thing you will
+need to make sure that Type::Tiny::XS is version 0.010 or newer since the older
 ones didn't support the 'Optional' method.
 
-This package will clone the passed arguments to L<build_class|/build_class> and 
-L<build_instance|/build_instance> since the references are destructivly parsed.  
+This package will clone the passed arguments to L<build_class|/build_class> and
+L<build_instance|/build_instance> since the references are destructivly parsed.
 If that is not what you want then use the method L<set_args_cloning
-|/set_args_cloning( $bool )> to manage the desired process.  Where this is likley 
-to go south is if your passed arguments contain a deep perl data set or reference 
-that you want shared.  In this case clone only the bits you want cloned on the 
+|/set_args_cloning( $bool )> to manage the desired process.  Where this is likley
+to go south is if your passed arguments contain a deep perl data set or reference
+that you want shared.  In this case clone only the bits you want cloned on the
 script side.
 
 =head1 Functions for Export
@@ -419,21 +416,21 @@ script side.
 
 =over
 
-B<Definition:> This method is used to create a Moose instance on the fly.  
-I<It assumes that you do not have the class pre-built and will look for the 
-needed information to compose a new class as well.>  Basically this passes the 
-%args intact to L<build_class|/build_class( %args|\%args )> first.  All the 
-relevant class building pieces will be used and removed from the args and then 
-this method will run $returned_class_name->new( %remaining_args ) with what is 
+B<Definition:> This method is used to create a Moose instance on the fly.
+I<It assumes that you do not have the class pre-built and will look for the
+needed information to compose a new class as well.>  Basically this passes the
+%args intact to L<build_class|/build_class( %args|\%args )> first.  All the
+relevant class building pieces will be used and removed from the args and then
+this method will run $returned_class_name->new( %remaining_args ) with what is
 left.
 
-B<Accepts:> a hash or hashref of arguments.  They must include the 
-necessary information to build a class.  I<(if you already have a class just 
-call $class-E<gt>new( %args ); instead of this method!)> This hashref can also 
-contain any attribute settings for the instance as well.  See 
+B<Accepts:> a hash or hashref of arguments.  They must include the
+necessary information to build a class.  I<(if you already have a class just
+call $class-E<gt>new( %args ); instead of this method!)> This hashref can also
+contain any attribute settings for the instance as well.  See
 L<build_class|/build_class( %args|\%args )> for more information.
 
-B<Returns:> This will return a blessed instance of your new class with 
+B<Returns:> This will return a blessed instance of your new class with
 the passed attribute settings implemented.
 
 =back
@@ -442,23 +439,23 @@ the passed attribute settings implemented.
 
 =over
 
-B<Definition:> This function is used to compose a Moose class on the fly.  The 
-the goal is to allow for as much or as little class definition as you want to be 
-provided by one function call.  The goal is also to remove as much of the boilerplate 
-and logic sequences for class building as possible and let this package handle that.  
-The function begins by using the L<Moose::Meta::Class>-E<gt>class(%args) method.  
-For this part the function specifically uses the argument callouts 'package', 
-'superclasses', and 'roles'.  Any necessary missing pieces will be provided. I<Even 
-though L<Moose::Meta::Class>-E<gt>class(%args) allows for the package name to be called 
-as the first element of an odd numbered list this implementation does not.  To define 
-a 'package' name it must be set as the value of the 'package' key in the %args.>  
-This function then takes the following arguements; 'add_attributes', 'add_methods', 
-and 'add_roles_in_sequence' and implements them in that order.   The 
-implementation of these values is done with L<Moose::Util> 'apply_all_roles' 
+B<Definition:> This function is used to compose a Moose class on the fly.  The
+the goal is to allow for as much or as little class definition as you want to be
+provided by one function call.  The goal is also to remove as much of the boilerplate
+and logic sequences for class building as possible and let this package handle that.
+The function begins by using the L<Moose::Meta::Class>-E<gt>class(%args) method.
+For this part the function specifically uses the argument callouts 'package',
+'superclasses', and 'roles'.  Any necessary missing pieces will be provided. I<Even
+though L<Moose::Meta::Class>-E<gt>class(%args) allows for the package name to be called
+as the first element of an odd numbered list this implementation does not.  To define
+a 'package' name it must be set as the value of the 'package' key in the %args.>
+This function then takes the following arguements; 'add_attributes', 'add_methods',
+and 'add_roles_in_sequence' and implements them in that order.   The
+implementation of these values is done with L<Moose::Util> 'apply_all_roles'
 and the meta capability in L<Moose>.
 
-B<Accepts:> a hash or hashref of arguments.  Six keys are stripped from the hash or 
-hash ref of arguments.  I<These keys are always used to build the class.  They are 
+B<Accepts:> a hash or hashref of arguments.  Six keys are stripped from the hash or
+hash ref of arguments.  I<These keys are always used to build the class.  They are
 never passed on to %remaining_args.>
 
 =over
@@ -467,9 +464,9 @@ B<The first three key-E<gt>value pairs are consumed simultaneously>.  They are;
 
 =over
 
-B<package:> This is the name (a string) that the new instance of 
-a this class is blessed under.  If this key is not provided the package 
-will generate a generic name.  This will L<overwrite|/WARNING> any class 
+B<package:> This is the name (a string) that the new instance of
+a this class is blessed under.  If this key is not provided the package
+will generate a generic name.  This will L<overwrite|/WARNING> any class
 built earlier with the same name.
 
 =over
@@ -478,7 +475,7 @@ B<accepts:> a string
 
 =back
 
-B<superclasses:> this is intentionally the same key from 
+B<superclasses:> this is intentionally the same key from
 Moose::Meta::Class-E<gt>create.
 
 =over
@@ -498,41 +495,41 @@ B<accepts:> a recognizable (by Moose) class name
 
 =back
 
-B<The second three key-E<gt>value pairs are consumed in the following 
+B<The second three key-E<gt>value pairs are consumed in the following
 sequence>.  They are;
 
 =over
 
-B<add_attributes:> this will add attributes to the class using the 
-L<Moose::Meta::Class>-E<gt>add_attribute method.  Because these definitions 
-are passed as key / value pairs in a hash ref they are not added in 
+B<add_attributes:> this will add attributes to the class using the
+L<Moose::Meta::Class>-E<gt>add_attribute method.  Because these definitions
+are passed as key / value pairs in a hash ref they are not added in
 any specific order.
 
 =over
 
-B<accepts:> a hash ref where the keys are attribute names and the values 
+B<accepts:> a hash ref where the keys are attribute names and the values
 are hash refs of the normal definitions used to define a Moose attribute.
 
 =back
 
 
-B<add_methods:>  this will add methods to the class using the 
-L<Moose::Meta::Class>-E<gt>add_method method.  Because these definitions 
-are passed as key / value pairs in a hash ref they are not added in 
+B<add_methods:>  this will add methods to the class using the
+L<Moose::Meta::Class>-E<gt>add_method method.  Because these definitions
+are passed as key / value pairs in a hash ref they are not added in
 any specific order.
 
 =over
 
-B<accepts:> a hash ref where the keys are method names and the values 
+B<accepts:> a hash ref where the keys are method names and the values
 are anonymous subroutines or subroutine references.
 
 =back
 
-B<add_roles_in_sequence:> this will compose, in sequence, each role in 
-the array ref into the class built on the prior three arguments using 
-L<Moose::Util> apply_all_roles.  This will allow an added role to 
-'require' elements of a role earlier in the sequence.  The roles 
-implemented with the L<role|/roles:> key are installed first and in a 
+B<add_roles_in_sequence:> this will compose, in sequence, each role in
+the array ref into the class built on the prior three arguments using
+L<Moose::Util> apply_all_roles.  This will allow an added role to
+'require' elements of a role earlier in the sequence.  The roles
+implemented with the L<role|/roles:> key are installed first and in a
 group. Then these roles are installed one at a time.
 
 =over
@@ -545,10 +542,10 @@ B<accepts:> an array ref list of roles recognizable (by Moose) as roles
 
 =back
 
-B<Returns:> This will check the caller and see if it wants an array or a 
-scalar.  In array context it returns the new class name and a hash ref of the 
-unused hash key/value pairs.  These are presumably the arguments for the 
-instance.  If the requested return is a scalar it just returns the name of 
+B<Returns:> This will check the caller and see if it wants an array or a
+scalar.  In array context it returns the new class name and a hash ref of the
+unused hash key/value pairs.  These are presumably the arguments for the
+instance.  If the requested return is a scalar it just returns the name of
 the newly created class.
 
 =back
@@ -557,7 +554,7 @@ the newly created class.
 
 =over
 
-This sets/changes the global variable 
+This sets/changes the global variable
 L<MooseX::ShortCut::BuildInstance::re_use_classes
 |/$MooseX::ShortCut::BuildInstance::re_use_classes>
 
@@ -567,7 +564,7 @@ L<MooseX::ShortCut::BuildInstance::re_use_classes
 
 =over
 
-This sets/changes the global variable 
+This sets/changes the global variable
 L<MooseX::ShortCut::BuildInstance::make_classes_immutable
 |/$MooseX::ShortCut::BuildInstance::make_classes_immutable>
 
@@ -577,7 +574,7 @@ L<MooseX::ShortCut::BuildInstance::make_classes_immutable
 
 =over
 
-This sets/changes the global variable 
+This sets/changes the global variable
 L<MooseX::ShortCut::BuildInstance::should_clone_args
 |/$MooseX::ShortCut::BuildInstance::should_clone_args>
 
@@ -587,25 +584,25 @@ L<MooseX::ShortCut::BuildInstance::should_clone_args
 
 =head2 $MooseX::ShortCut::BuildInstance::anonymous_class_count
 
-This is an integer that increments and appends to the anonymous package name 
+This is an integer that increments and appends to the anonymous package name
 for each new anonymous package (class) created.
 
 =head2 $MooseX::ShortCut::BuildInstance::built_classes
 
-This is a hashref that tracks the class names ('package's) built buy this class 
+This is a hashref that tracks the class names ('package's) built buy this class
 to manage duplicate build behaviour.
 
 =head2 $MooseX::ShortCut::BuildInstance::re_use_classes
 
-This is a boolean (1|0) variable that tracks if the class should overwrite or 
-re-use a package name (and the defined class) from a prior 'build_class' call.  
-If the package name is overwritten it will L<cluck|https://metacpan.org/pod/Carp#SYNOPSIS> 
-in warning since any changes will affect active instances of prior class builds 
-with the same name.  If you wish to avoid changing old built behaviour at the risk 
-of not installing new behaviour then set this variable to true.  I<No warning will 
-be provided if new requested class behaviour is discarded.> The class reuse behaviour 
+This is a boolean (1|0) variable that tracks if the class should overwrite or
+re-use a package name (and the defined class) from a prior 'build_class' call.
+If the package name is overwritten it will L<cluck|https://metacpan.org/pod/Carp#SYNOPSIS>
+in warning since any changes will affect active instances of prior class builds
+with the same name.  If you wish to avoid changing old built behaviour at the risk
+of not installing new behaviour then set this variable to true.  I<No warning will
+be provided if new requested class behaviour is discarded.> The class reuse behaviour
 can be changed with the exported method L<should_re_use_classes
-|/should_re_use_classes( $bool )>.  This does not apply to pre-loaded classes.  
+|/should_re_use_classes( $bool )>.  This does not apply to pre-loaded classes.
 For pre-loaded classes this package will cluck and then overwrite every time.
 
 =over
@@ -616,7 +613,7 @@ B<Default:> False = warn then overwrite
 
 =head2 $MooseX::ShortCut::BuildInstance::make_classes_immutable
 
-This is a boolean (1|0) variable that manages whether a class is immutabilized at the end of 
+This is a boolean (1|0) variable that manages whether a class is immutabilized at the end of
 creation.  This can be changed with the exported method L<set_class_immutability
 |/set_class_immutability( $bool )>.
 
@@ -628,13 +625,13 @@ B<Default:> True = always immutabilize classes after building
 
 =head2 $MooseX::ShortCut::BuildInstance::should_clone_args
 
-This is a boolean (1|0) variable that manages whether a the arguments passed to 
+This is a boolean (1|0) variable that manages whether a the arguments passed to
 L<build_instance|/build_instance( %argsE<verbar>\%args )> and L<build_class
-|/build_class( %argsE<verbar>\%args )> are cloned (using L<Clone> )  the arguments 
-to both of these are processed destructivly so generally you would want them cloned 
-but not in every case.  If you want cloning to be managed on the script side set this 
-global variable to 0.  Where this is likley to be helpful is if your passed arguments 
-contain a deep perl data set or reference that you want shared.  In this case clone only 
+|/build_class( %argsE<verbar>\%args )> are cloned (using L<Clone> )  the arguments
+to both of these are processed destructivly so generally you would want them cloned
+but not in every case.  If you want cloning to be managed on the script side set this
+global variable to 0.  Where this is likley to be helpful is if your passed arguments
+contain a deep perl data set or reference that you want shared.  In this case clone only
 the bits you want cloned on the script side.
 
 =over
@@ -646,9 +643,9 @@ B<Default:> True = always clone arguments
 =head1 Build/Install from Source
 
 =over
-	
+
 B<1.> Download a compressed file with the code
-	
+
 B<2.> Extract the code from the compressed file.
 
 =over
@@ -656,7 +653,7 @@ B<2.> Extract the code from the compressed file.
 If you are using tar this should work:
 
 	tar -zxvf Spreadsheet-XLSX-Reader-LibXML-v0.xx.tar.gz
-	
+
 =back
 
 B<3.> Change (cd) into the extracted directory
@@ -668,9 +665,9 @@ B<4.> Run the following
 (For Windows find what version of make was used to compile your perl)
 
 	perl  -V:make
-	
+
 (for Windows below substitute the correct make function (s/make/dmake/g)?)
-	
+
 =back
 
 	>perl Makefile.PL
@@ -682,7 +679,7 @@ B<4.> Run the following
 	>make install # As sudo/root
 
 	>make clean
-	
+
 =back
 
 =head1 SUPPORT
@@ -700,6 +697,8 @@ L<MooseX-ShortCut-BuildInstance/issues|https://github.com/jandrew/MooseX-ShortCu
 B<1.> L<Increase test coverage
 |https://coveralls.io/github/jandrew/MooseX-ShortCut-BuildInstance?branch=master>
 
+B<2.> Add an explicit import call as an action key in 'build_class'
+
 =back
 
 =head1 AUTHOR
@@ -728,7 +727,7 @@ This software is copyrighted (c) 2012, 2016 by Jed Lund
 
 L<version>
 
-L<5.010|http://perldoc.perl.org/perl5100delta.html> (for use of 
+L<5.010|http://perldoc.perl.org/perl5100delta.html> (for use of
 L<defined or|http://perldoc.perl.org/perlop.html#Logical-Defined-Or> //)
 
 L<Moose>
